import { defineConfig, normalizePath, Plugin, loadEnv } from "vite";
import vue from "@vitejs/plugin-vue";
import ViteComponents from "unplugin-vue-components/vite";
import { AntDesignVueResolver } from "unplugin-vue-components/resolvers";

const path = require("path");

// https://vitejs.dev/config/
export default defineConfig(({ command, mode }) => {
  const env = loadEnv(mode, process.cwd(), "");
  const isDev = command === "serve"; // 开发环境下 command 为 'serve'，生产环境为 'build'

  // console.log("当前环境：", {
  //   command, // 'serve' 或 'build'
  //   mode, // 'development' 或 'production'
  //   isDev, // true 或 false
  // });

  return {
    base: isDev ? env.VITE_APP_DEV_BASE_URL : undefined,
    plugins: [
      vue({
        reactivityTransform: true,
      }),
      ViteComponents({
        resolvers: [AntDesignVueResolver()],
        dts: true,
      }),
    ],
    server: {
      port: 9000,
      // strictPort: true,
      fs: {
        strict: true,
        allow: ["./"],
      },
      proxy: {
        "/login": {
          target: env.VITE_APP_DEV_PROXY,
          changeOrigin: true,
        },
        "/mark": {
          target: env.VITE_APP_DEV_PROXY,
          changeOrigin: true,
        },
        "/admin": {
          target: env.VITE_APP_DEV_PROXY,
          changeOrigin: true,
        },
        "/api": {
          target: env.VITE_APP_DEV_PROXY,
          // changeOrigin: true,
        },
      },
    },
    resolve: {
      alias: [{ find: "@", replacement: path.resolve(__dirname, "./src") }],
      extensions: [".js", ".mjs", ".ts", ".vue", ".json", ".scss", ".css"],
    },
    build: {
      ssr: false,
      commonjsOptions: { include: [] },
    },
    optimizeDeps: {
      disabled: false,
    },
    // define: {
    //   __VUE_PROD_DEVTOOLS__: true, // no effect
    // },
  };
});
